@@ -194,7 +194,7 @@ _g_substitute (const char *from,
 
 char *
 _g_substitute_pattern (const char *utf8_text, 
-		       char        pattern, 
+		       gunichar    pattern, 
 		       const char *value)
 {
 	const char *s;
@@ -257,8 +257,8 @@ _g_utf8_strndup (const char *str,
 
 
 char **
-_g_utf8_strsplit (const char *str,
-		  const char  delimiter)
+_g_utf8_strsplit (const char     *str,
+		  const gunichar  delimiter)
 {
 	GSList      *slist = NULL, *scan;
 	char       **str_array;
@@ -333,6 +333,23 @@ _g_utf8_strstrip (const char *str)
 }
 
 
+gboolean
+_g_utf8_all_spaces (const char *utf8_string)
+{
+	gunichar c;
+	
+	c = g_utf8_get_char (utf8_string);
+	while (c != 0) {
+		if (! g_unichar_isspace (c))
+			return FALSE;
+		utf8_string = g_utf8_next_char (utf8_string);
+		c = g_utf8_get_char (utf8_string);
+	}
+
+	return TRUE;
+}
+
+
 void
 debug (const char *file,
        int         line,
